==> quick-react-notification-1.0.1.tgz: package/es/context/notification-context.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useContext, useMemo, createContext, useReducer } from 'react';
import { Portal } from 'react-portal';
import { v4 as uuidv4 } from 'uuid';
import Notification from '../components/Notification';
var types = {
  addNotification: 'addNotification',
  removeNotification: 'removeNotification'
};
var NotificationContext = createContext();

function notificationReducer(state, action) {
  switch (action.type) {
    case types.addNotification:
      {
        var _action$payload = action.payload,
            message = _action$payload.message,
            type = _action$payload.type,
            id = _action$payload.id;
        return _extends({}, state, {
          notifications: [].concat(state.notifications, [{
            id: id,
            isOpen: true,
            message: message,
            type: type
          }])
        });
      }

    case types.removeNotification:
      return _extends({}, state, {
        notifications: state.notifications.filter(function (item) {
          return item.id !== action.payload.id;
        })
      });

    default:
      throw new Error("'" + action.type + "': invalid type received.");
  }
}

function NotificaionProvider(_ref) {
  var _state$notifications;

  var children = _ref.children;

  var _useReducer = useReducer(notificationReducer, {
    notifications: []
  }),
      state = _useReducer[0],
      dispatch = _useReducer[1];

  function removeNotification(id) {
    dispatch({
      type: types.removeNotification,
      payload: {
        id: id
      }
    });
  }

  function showNotification(_ref2) {
    var _ref2$type = _ref2.type,
        type = _ref2$type === void 0 ? 'error' : _ref2$type,
        _ref2$message = _ref2.message,
        message = _ref2$message === void 0 ? 'Something went wrong' : _ref2$message,
        _ref2$autoHide = _ref2.autoHide,
        autoHide = _ref2$autoHide === void 0 ? true : _ref2$autoHide,
        _ref2$hideAfter = _ref2.hideAfter,
        hideAfter = _ref2$hideAfter === void 0 ? 3000 : _ref2$hideAfter;
    var id = uuidv4();
    dispatch({
      type: types.addNotification,
      payload: {
        type: type,
        message: message,
        id: id
      }
    });

    if (autoHide) {
      setTimeout(function () {
        removeNotification(id);
      }, hideAfter);
    }
  }

  var value = useMemo(function () {
    return {
      showNotification: showNotification,
      removeNotification: removeNotification
    };
  }, []);
  return /*#__PURE__*/React.createElement(NotificationContext.Provider, {
    value: value
  }, /*#__PURE__*/React.createElement(Portal, null, /*#__PURE__*/React.createElement("div", {
    style: {
      position: 'fixed',
      top: '10px',
      right: '10px',
      display: 'flex',
      flexDirection: 'column',
      alignItems: 'flex-end'
    }
  }, (_state$notifications = state.notifications) === null || _state$notifications === void 0 ? void 0 : _state$notifications.map(function (_ref3) {
    var id = _ref3.id,
        isOpen = _ref3.isOpen,
        message = _ref3.message,
        type = _ref3.type;
    return /*#__PURE__*/React.createElement(Notification, {
      key: id,
      id: id,
      type: type,
      message: message,
      isOpen: isOpen
    });
  }))), children);
}

function useNotification() {
  var context = useContext(NotificationContext);

  if (!context) {
    throw new Error('useNotification must be used within a NotificationProvider');
  }

  return context;
}

export { NotificaionProvider, useNotification };

==> quick-react-notification-1.0.3.tgz: package/es/context/notification-context.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useContext, useMemo, createContext, useReducer } from 'react';
import { Portal } from 'react-portal';
import { v4 as uuidv4 } from 'uuid';
import Notification from '../components/Notification';
var types = {
  addNotification: 'addNotification',
  removeNotification: 'removeNotification'
};
var NotificationContext = createContext();

function notificationReducer(state, action) {
  switch (action.type) {
    case types.addNotification:
      {
        var _action$payload = action.payload,
            message = _action$payload.message,
            type = _action$payload.type,
            id = _action$payload.id;
        return _extends({}, state, {
          notifications: [].concat(state.notifications, [{
            id: id,
            isOpen: true,
            message: message,
            type: type
          }])
        });
      }

    case types.removeNotification:
      return _extends({}, state, {
        notifications: state.notifications.filter(function (item) {
          return item.id !== action.payload.id;
        })
      });

    default:
      throw new Error("'" + action.type + "': invalid type received.");
  }
}

function NotificationProvider(_ref) {
  var _state$notifications;

  var children = _ref.children;

  var _useReducer = useReducer(notificationReducer, {
    notifications: []
  }),
      state = _useReducer[0],
      dispatch = _useReducer[1];

  function removeNotification(id) {
    dispatch({
      type: types.removeNotification,
      payload: {
        id: id
      }
    });
  }
  /**
   * Adds a new notification
   * @param config Customise Notification.
   * @param config.type ["success", "warning", "info", "error"] Customise Notification.
   */


  function showNotification(_ref2) {
    var _ref2$type = _ref2.type,
        type = _ref2$type === void 0 ? 'error' : _ref2$type,
        _ref2$message = _ref2.message,
        message = _ref2$message === void 0 ? 'Something went wrong' : _ref2$message,
        _ref2$autoHide = _ref2.autoHide,
        autoHide = _ref2$autoHide === void 0 ? true : _ref2$autoHide,
        _ref2$hideAfter = _ref2.hideAfter,
        hideAfter = _ref2$hideAfter === void 0 ? 3000 : _ref2$hideAfter;
    var id = uuidv4();
    dispatch({
      type: types.addNotification,
      payload: {
        type: type,
        message: message,
        id: id
      }
    });

    if (autoHide) {
      setTimeout(function () {
        removeNotification(id);
      }, hideAfter);
    }
  }

  var value = useMemo(function () {
    return {
      showNotification: showNotification,
      removeNotification: removeNotification
    };
  }, []);
  return /*#__PURE__*/React.createElement(NotificationContext.Provider, {
    value: value
  }, /*#__PURE__*/React.createElement(Portal, null, /*#__PURE__*/React.createElement("div", {
    style: {
      position: 'fixed',
      top: '10px',
      right: '10px',
      display: 'flex',
      flexDirection: 'column',
      alignItems: 'flex-end'
    }
  }, (_state$notifications = state.notifications) === null || _state$notifications === void 0 ? void 0 : _state$notifications.map(function (_ref3) {
    var id = _ref3.id,
        isOpen = _ref3.isOpen,
        message = _ref3.message,
        type = _ref3.type;
    return /*#__PURE__*/React.createElement(Notification, {
      key: id,
      id: id,
      type: type,
      message: message,
      isOpen: isOpen
    });
  }))), children);
}

function useNotification() {
  var context = useContext(NotificationContext);

  if (!context) {
    throw new Error('useNotification must be used within a NotificationProvider');
  }

  return context;
}

export { NotificationProvider, useNotification };
